@@ -38,28 +38,43 @@ my %hierarchy = (
     'AddMasterSlide' => 'Task',
     'AddShape' => 'Task',
     'AddSlide' => 'Task',
+    'AlphaBiLevelEffect' => 'ImageTransformEffect',
+    'AlphaCeilingEffect' => 'ImageTransformEffect',
+    'AlphaFloorEffect' => 'ImageTransformEffect',
+    'AlphaInverseEffect' => 'ImageTransformEffect',
+    'AlphaModulateEffect' => 'ImageTransformEffect',
+    'AlphaModulateFixedEffect' => 'ImageTransformEffect',
+    'AlphaReplaceEffect' => 'ImageTransformEffect',
     'ArcToPathSegment' => 'PathSegment',
     'ArrayElement' => 'MathElement',
     'BarElement' => 'MathElement',
     'Base64InputFile' => 'InputFile',
+    'BiLevelEffect' => 'ImageTransformEffect',
     'BlockElement' => 'MathElement',
+    'BlurImageEffect' => 'ImageTransformEffect',
     'BorderBoxElement' => 'MathElement',
     'BoxElement' => 'MathElement',
     'ClosePathSegment' => 'PathSegment',
+    'ColorChangeEffect' => 'ImageTransformEffect',
+    'ColorReplaceEffect' => 'ImageTransformEffect',
     'ColorScheme' => 'ResourceBase',
     'CubicBezierToPathSegment' => 'PathSegment',
     'DelimiterElement' => 'MathElement',
     'Document' => 'ResourceBase',
     'DocumentProperties' => 'ResourceBase',
     'DocumentProperty' => 'ResourceBase',
+    'DuotoneEffect' => 'ImageTransformEffect',
     'FileVersion' => 'StorageFile',
+    'FillOverlayImageEffect' => 'ImageTransformEffect',
     'FontScheme' => 'ResourceBase',
     'FormatScheme' => 'ResourceBase',
     'FractionElement' => 'MathElement',
     'FunctionElement' => 'MathElement',
     'GradientFill' => 'FillFormat',
+    'GrayScaleEffect' => 'ImageTransformEffect',
     'GroupingCharacterElement' => 'MathElement',
     'HeaderFooter' => 'ResourceBase',
+    'HslEffect' => 'ImageTransformEffect',
     'Html5ExportOptions' => 'ExportOptions',
     'HtmlExportOptions' => 'ExportOptions',
     'Image' => 'ResourceBase',
@@ -70,6 +85,7 @@ my %hierarchy = (
     'LeftSubSuperscriptElement' => 'MathElement',
     'LimitElement' => 'MathElement',
     'LineToPathSegment' => 'PathSegment',
+    'LuminanceEffect' => 'ImageTransformEffect',
     'MasterSlide' => 'ResourceBase',
     'MasterSlides' => 'ResourceBase',
     'MatrixElement' => 'MathElement',
@@ -129,6 +145,7 @@ my %hierarchy = (
     'TextElement' => 'MathElement',
     'TextItems' => 'ResourceBase',
     'Theme' => 'ResourceBase',
+    'TintEffect' => 'ImageTransformEffect',
     'UpdateBackground' => 'Task',
     'UpdateShape' => 'Task',
     'VideoExportOptions' => 'ExportOptions',
@@ -136,7 +153,6 @@ my %hierarchy = (
     'XYSeries' => 'Series',
     'XamlExportOptions' => 'ExportOptions',
     'XpsExportOptions' => 'ExportOptions',
-    'BoxAndWhiskerSeries' => 'OneValueSeries',
     'BubbleChartDataPoint' => 'ScatterChartDataPoint',
     'BubbleSeries' => 'XYSeries',
     'Chart' => 'ShapeBase',
@@ -153,8 +169,6 @@ my %hierarchy = (
     'SummaryZoomFrame' => 'ShapeBase',
     'Table' => 'ShapeBase',
     'TiffExportOptions' => 'ImageExportOptionsBase',
-    'WaterfallChartDataPoint' => 'OneValueChartDataPoint',
-    'WaterfallSeries' => 'OneValueSeries',
     'ZoomObject' => 'ShapeBase',
     'AudioFrame' => 'GeometryShape',
     'Connector' => 'GeometryShape',
@@ -205,6 +219,7 @@ my %determiners = (
     'Hyperlink' => {  },
     'IShapeExportOptions' => {  },
     'ImageExportFormat' => {  },
+    'ImageTransformEffect' => {  },
     'InnerShadowEffect' => {  },
     'Input' => {  },
     'InputFile' => {  },
@@ -259,28 +274,43 @@ my %determiners = (
     'AddMasterSlide' => { 'Type' => 'AddMasterSlide', },
     'AddShape' => { 'Type' => 'AddShape', },
     'AddSlide' => { 'Type' => 'AddSlide', },
+    'AlphaBiLevelEffect' => { 'Type' => 'AlphaBiLevel', },
+    'AlphaCeilingEffect' => { 'Type' => 'AlphaCeiling', },
+    'AlphaFloorEffect' => { 'Type' => 'AlphaFloor', },
+    'AlphaInverseEffect' => { 'Type' => 'AlphaInverse', },
+    'AlphaModulateEffect' => { 'Type' => 'AlphaModulate', },
+    'AlphaModulateFixedEffect' => { 'Type' => 'AlphaModulateFixed', },
+    'AlphaReplaceEffect' => { 'Type' => 'AlphaReplace', },
     'ArcToPathSegment' => { 'Type' => 'ArcTo', },
     'ArrayElement' => { 'Type' => 'Array', },
     'BarElement' => { 'Type' => 'Bar', },
     'Base64InputFile' => { 'Type' => 'Base64', },
+    'BiLevelEffect' => { 'Type' => 'BiLevel', },
     'BlockElement' => { 'Type' => 'Block', },
+    'BlurImageEffect' => { 'Type' => 'Blur', },
     'BorderBoxElement' => { 'Type' => 'BorderBox', },
     'BoxElement' => { 'Type' => 'Box', },
     'ClosePathSegment' => { 'Type' => 'Close', },
+    'ColorChangeEffect' => { 'Type' => 'ColorChange', },
+    'ColorReplaceEffect' => { 'Type' => 'ColorReplace', },
     'ColorScheme' => {  },
     'CubicBezierToPathSegment' => { 'Type' => 'CubicBezierTo', },
     'DelimiterElement' => { 'Type' => 'Delimiter', },
     'Document' => {  },
     'DocumentProperties' => {  },
     'DocumentProperty' => {  },
+    'DuotoneEffect' => { 'Type' => 'Duotone', },
     'FileVersion' => {  },
+    'FillOverlayImageEffect' => { 'Type' => 'FillOverlay', },
     'FontScheme' => {  },
     'FormatScheme' => {  },
     'FractionElement' => { 'Type' => 'Fraction', },
     'FunctionElement' => { 'Type' => 'Function', },
     'GradientFill' => { 'Type' => 'Gradient', },
+    'GrayScaleEffect' => { 'Type' => 'GrayScale', },
     'GroupingCharacterElement' => { 'Type' => 'GroupingCharacter', },
     'HeaderFooter' => {  },
+    'HslEffect' => { 'Type' => 'Hsl', },
     'Html5ExportOptions' => { 'Format' => 'html5', },
     'HtmlExportOptions' => { 'Format' => 'html', },
     'Image' => {  },
@@ -291,6 +321,7 @@ my %determiners = (
     'LeftSubSuperscriptElement' => { 'Type' => 'LeftSubSuperscriptElement', },
     'LimitElement' => { 'Type' => 'Limit', },
     'LineToPathSegment' => { 'Type' => 'LineTo', },
+    'LuminanceEffect' => { 'Type' => 'Luminance', },
     'MasterSlide' => {  },
     'MasterSlides' => {  },
     'MatrixElement' => { 'Type' => 'Matrix', },
@@ -350,6 +381,7 @@ my %determiners = (
     'TextElement' => { 'Type' => 'Text', },
     'TextItems' => {  },
     'Theme' => {  },
+    'TintEffect' => { 'Type' => 'Tint', },
     'UpdateBackground' => { 'Type' => 'UpdateBackground', },
     'UpdateShape' => { 'Type' => 'UpdateShape', },
     'VideoExportOptions' => { 'Format' => 'mpeg4', },
@@ -357,7 +389,6 @@ my %determiners = (
     'XYSeries' => {  },
     'XamlExportOptions' => { 'Format' => 'xaml', },
     'XpsExportOptions' => { 'Format' => 'xps', },
-    'BoxAndWhiskerSeries' => { 'DataPointType' => 'OneValue', },
     'BubbleChartDataPoint' => {  },
     'BubbleSeries' => { 'DataPointType' => 'Bubble', },
     'Chart' => { 'Type' => 'Chart', },
@@ -374,8 +405,6 @@ my %determiners = (
     'SummaryZoomFrame' => { 'Type' => 'SummaryZoomFrame', },
     'Table' => { 'Type' => 'Table', },
     'TiffExportOptions' => { 'Format' => 'tiff', },
-    'WaterfallChartDataPoint' => {  },
-    'WaterfallSeries' => { 'DataPointType' => 'OneValue', },
     'ZoomObject' => {  },
     'AudioFrame' => { 'Type' => 'AudioFrame', },
     'Connector' => { 'Type' => 'Connector', },
